package org.jeecg.api.service;

import org.jeecg.api.bean.PageBean;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.commonAddress.entity.CommonAddress;
import org.jeecg.modules.commonHelp.entity.CommonHelp;

import java.math.BigDecimal;

public interface AppletInfoService {

    //修改个人信息接口
    Result<?> updateUserInfo(String token,String nickName,String headImage,String phone);


    //查看个人信息接口
    Result<?> getUserInfo(String token);


    //查询地址信息列表带分页
    Result<?> getAddressList(String token, PageBean pageBean);


    //查询地址信息详情
    Result<?> getAddressInfo(String token,String id);


    //增加或修改地址信息
    Result<?> saveOrUpdateAddress(String token, CommonAddress commonAddress);


    //修改默认地址
    Result<?> updateDefaultAddress(String token,String id);



    //删除地址信息
    Result<?> deleteAddress(String token,String id);


    //我的团队相关信息列表带分页
    Result<?> getTeamList(String token, Integer state,PageBean pageBean);


    //获取团队头部信息
    Result<?> getTeamHeader(String token);


    //提现
    Result<?> openMoney (String token, BigDecimal money);


    //流水记录带分页搜索
    Result<?> getLogList(String token,String timeDate,PageBean pageBean);


    //生成邀请二维码
    Result<?> createQrCode(String token);


    //获取个人邀请码
    byte[] getInviteCode2(String token);

    //新增帮助反馈信息
    Result<?> addHelp(String token, CommonHelp commonHelp);

}
